@@ -1,14 +1,10 @@
 import kubernetes
 
 from ocp_resources.constants import PROTOCOL_ERROR_EXCEPTION_DICT, TIMEOUT_4MINUTES
-from ocp_resources.logger import get_logger
 from ocp_resources.resource import NamespacedResource
 from ocp_resources.utils import TimeoutSampler
 
 
-LOGGER = get_logger(name=__name__)
-
-
 class DaemonSet(NamespacedResource):
     """
     DaemonSet object.
@@ -26,7 +22,7 @@ class DaemonSet(NamespacedResource):
         Raises:
             TimeoutExpiredError: If not all the pods are deployed.
         """
-        LOGGER.info(f"Wait for {self.kind} {self.name} to deploy all desired pods")
+        self.logger.info(f"Wait for {self.kind} {self.name} to deploy all desired pods")
         samples = TimeoutSampler(
             wait_timeout=timeout,
             sleep=1,
