@@ -2,4 +2,4 @@ from ocp_resources.resource import NamespacedResource
 
 
 class VirtualMachinePreference(NamespacedResource):
-    api_group = NamespacedResource.ApiGroup.INSTANCE_TYPE_KUBEVIRT_IO
+    api_group = NamespacedResource.ApiGroup.INSTANCETYPE_KUBEVIRT_IO
